==> permissions_kiosk-0.0.2.tar.gz: android/src/main/java/com/DevAsh/permissions_kiosk/PermissionsKioskPlugin.java <==
package com.DevAsh.permissions_kiosk;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import android.content.Intent;
import android.provider.Settings;
import android.content.Context;
import android.net.Uri;
import android.app.Activity;
import android.app.AppOpsManager;
import android.content.pm.PackageManager;
import android.Manifest;
import android.content.pm.ResolveInfo;
import android.content.ComponentName;
import 	android.content.IntentFilter;
import java.util.ArrayList;
import java.util.*;

/** PermissionsKioskPlugin */
public class PermissionsKioskPlugin implements MethodCallHandler {
  
  Activity context;
  PermissionsKioskPlugin(Activity content){
       this.context=content;
  }
  /** Plugin registration. */
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "permissions_kiosk");
    channel.setMethodCallHandler(new PermissionsKioskPlugin(registrar.activity()));
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    }else if (call.method.equals("isWriteSettings")) {
      boolean settingsCanWrite = Settings.System.canWrite(context);
      result.success(settingsCanWrite);
    }else if (call.method.equals("getWriteSettings")) {
          Intent intent = new Intent(Settings.ACTION_MANAGE_WRITE_SETTINGS, Uri.parse("package:" + context.getPackageName()));
          context.startActivityForResult(intent, 200);
    }else if (call.method.equals("isUsageSettings")) {
           AppOpsManager appOps = (AppOpsManager) context.getSystemService(Context.APP_OPS_SERVICE);
           int mode = appOps.checkOpNoThrow(AppOpsManager.OPSTR_GET_USAGE_STATS,android.os.Process.myUid(), context.getPackageName());
           boolean granted;
           if (mode == AppOpsManager.MODE_DEFAULT) {
             granted = (context.checkCallingOrSelfPermission(android.Manifest.permission.PACKAGE_USAGE_STATS) == PackageManager.PERMISSION_GRANTED);
           } else {
             granted = (mode == AppOpsManager.MODE_ALLOWED);
           }
           result.success(granted);
           
    }else if (call.method.equals("getUsageSettings")) {
         
      context.startActivity(new Intent(Settings.ACTION_USAGE_ACCESS_SETTINGS));
      
    }else if (call.method.equals("isDrawSettings")) {
         result.success(Settings.canDrawOverlays(context));
    }else if (call.method.equals("getDrawSettings")) {
         Intent intent = new Intent(Settings.ACTION_MANAGE_OVERLAY_PERMISSION, Uri.parse("package:" + context.getPackageName()));
         context.startActivityForResult(intent, 0);
    }else if (call.method.equals("currentLauncher")) {
      result.success(isMyAppLauncherDefault());
          
 
    }else if (call.method.equals("setLauncher")) { 

     

      context.startActivity(new Intent(Settings.ACTION_HOME_SETTINGS));

      // Intent intent = new Intent("android.intent.action.MAIN");
      // intent.addCategory("android.intent.category.HOME");
      // intent.addFlags(Intent.FLAG_RECEIVER_FOREGROUND);
      // context.startActivity(intent);
    }

    else {
       result.notImplemented();
     }
 }


 private boolean isMyAppLauncherDefault() {
  final IntentFilter filter = new IntentFilter(Intent.ACTION_MAIN);
  filter.addCategory(Intent.CATEGORY_HOME);

  List<IntentFilter> filters = new ArrayList<IntentFilter>();
  filters.add(filter);

  final String myPackageName = context.getPackageName();
  List<ComponentName> activities = new ArrayList<ComponentName>();
  final PackageManager packageManager = (PackageManager) context.getPackageManager();

  packageManager.getPreferredActivities(filters, activities, null);

  for (ComponentName activity : activities) {
      if (myPackageName.equals(activity.getPackageName())) {
          return true;
      }
  }
  return false;
 }   
}

==> permissions_kiosk-0.0.3.tar.gz: android/src/main/java/com/DevAsh/permissions_kiosk/PermissionsKioskPlugin.java <==
package com.DevAsh.permissions_kiosk;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import android.content.Intent;
import android.provider.Settings;
import android.content.Context;
import android.net.Uri;
import android.app.Activity;
import android.app.AppOpsManager;
import android.content.pm.PackageManager;
import android.Manifest;
import android.content.pm.ResolveInfo;
import android.content.ComponentName;
import 	android.content.IntentFilter;
import java.util.ArrayList;
import java.util.*;

/** PermissionsKioskPlugin */
public class PermissionsKioskPlugin implements MethodCallHandler {
  
  Activity context;
  PermissionsKioskPlugin(Activity content){
       this.context=content;
  }
  /** Plugin registration. */
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "permissions_kiosk");
    channel.setMethodCallHandler(new PermissionsKioskPlugin(registrar.activity()));
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    }else if (call.method.equals("isWriteSettings")) {
      boolean settingsCanWrite = Settings.System.canWrite(context);
      result.success(settingsCanWrite);
    }else if (call.method.equals("getWriteSettings")) {
          Intent intent = new Intent(Settings.ACTION_MANAGE_WRITE_SETTINGS, Uri.parse("package:" + context.getPackageName()));
          context.startActivityForResult(intent, 200);
    }else if (call.method.equals("isUsageSettings")) {
           AppOpsManager appOps = (AppOpsManager) context.getSystemService(Context.APP_OPS_SERVICE);
           int mode = appOps.checkOpNoThrow(AppOpsManager.OPSTR_GET_USAGE_STATS,android.os.Process.myUid(), context.getPackageName());
           boolean granted;
           if (mode == AppOpsManager.MODE_DEFAULT) {
             granted = (context.checkCallingOrSelfPermission(android.Manifest.permission.PACKAGE_USAGE_STATS) == PackageManager.PERMISSION_GRANTED);
           } else {
             granted = (mode == AppOpsManager.MODE_ALLOWED);
           }
           result.success(granted);
           
    }else if (call.method.equals("getUsageSettings")) {
         
      context.startActivity(new Intent(Settings.ACTION_USAGE_ACCESS_SETTINGS));
      
    }else if (call.method.equals("isDrawSettings")) {
         result.success(Settings.canDrawOverlays(context));
    }else if (call.method.equals("getDrawSettings")) {
         Intent intent = new Intent(Settings.ACTION_MANAGE_OVERLAY_PERMISSION, Uri.parse("package:" + context.getPackageName()));
         context.startActivityForResult(intent, 0);
    }else if (call.method.equals("currentLauncher")) {
      result.success(isMyAppLauncherDefault());
          
 
    }else if (call.method.equals("setLauncher")) { 
      context.getPackageManager().clearPackagePreferredActivities(context.getPackageName());
      resetPreferredLauncherAndOpenChooser(context);

      // context.startActivity(new Intent(Settings.ACTION_HOME_SETTINGS));

      // Intent intent = new Intent("android.intent.action.MAIN");
      // intent.addCategory("android.intent.category.HOME");
      // intent.addFlags(Intent.FLAG_RECEIVER_FOREGROUND);
      // context.startActivity(intent);
      
    }

    else {
       result.notImplemented();
     }
 }


 private boolean isMyAppLauncherDefault() {
  final IntentFilter filter = new IntentFilter(Intent.ACTION_MAIN);
  filter.addCategory(Intent.CATEGORY_HOME);

  List<IntentFilter> filters = new ArrayList<IntentFilter>();
  filters.add(filter);

  final String myPackageName = context.getPackageName();
  List<ComponentName> activities = new ArrayList<ComponentName>();
  final PackageManager packageManager = (PackageManager) context.getPackageManager();

  packageManager.getPreferredActivities(filters, activities, null);

  for (ComponentName activity : activities) {
      if (myPackageName.equals(activity.getPackageName())) {
          return true;
      }
  }
  return false;
 }   


 public static void resetPreferredLauncherAndOpenChooser(Context context) {
  PackageManager packageManager = context.getPackageManager();
  ComponentName componentName = new ComponentName(context, context.getClass());
  packageManager.setComponentEnabledSetting(componentName, PackageManager.COMPONENT_ENABLED_STATE_ENABLED, PackageManager.DONT_KILL_APP);

  Intent selector = new Intent(Intent.ACTION_MAIN);
  selector.addCategory(Intent.CATEGORY_HOME);
  selector.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
  context.startActivity(selector);

  packageManager.setComponentEnabledSetting(componentName, PackageManager.COMPONENT_ENABLED_STATE_DEFAULT, PackageManager.DONT_KILL_APP);
}
}
